summaryrefslogtreecommitdiff
path: root/src/select/computed.h
diff options
context:
space:
mode:
authorMichael Drake <tlsa@netsurf-browser.org>2014-11-16 15:18:00 +0000
committerMichael Drake <tlsa@netsurf-browser.org>2014-11-16 15:18:00 +0000
commit34271c0f32bca359af8f7a6c40f166d402b78eb6 (patch)
treee275a43f740f7baeb6d0e41bed3ef8de1de27e87 /src/select/computed.h
parent34fc236550a686d947458a2ce7f9a081b2b6d22c (diff)
downloadlibcss-34271c0f32bca359af8f7a6c40f166d402b78eb6.tar.gz
libcss-34271c0f32bca359af8f7a6c40f166d402b78eb6.tar.bz2
Add column-rule-width to computed styles.
Diffstat (limited to 'src/select/computed.h')
-rw-r--r--src/select/computed.h27
1 files changed, 15 insertions, 12 deletions
diff --git a/src/select/computed.h b/src/select/computed.h
index 71a3916..39904f9 100644
--- a/src/select/computed.h
+++ b/src/select/computed.h
@@ -22,12 +22,13 @@ typedef struct css_computed_uncommon {
* column_gap 2 + 4 4
* column_rule_color 2 4
* column_rule_style 4 0
+ * column_rule_width 3 + 4 4
* letter_spacing 2 + 4 4
* outline_color 2 4
* outline_width 3 + 4 4
* word_spacing 2 + 4 4
* --- ---
- * 68 bits 52 bytes
+ * 75 bits 56 bytes
*
* Encode counter_increment and _reset as an array of name, value pairs,
* terminated with a blank entry.
@@ -51,27 +52,28 @@ typedef struct css_computed_uncommon {
* 2 bits sizeof(ptr)
*
* ___ ___
- * 81 bits 52 + 4sizeof(ptr) bytes
+ * 88 bits 58 + 4sizeof(ptr) bytes
*
- * 10 bytes 52 + 4sizeof(ptr) bytes
+ * 11 bytes 58 + 4sizeof(ptr) bytes
* ===================
- * 62 + 4sizeof(ptr) bytes
+ * 67 + 4sizeof(ptr) bytes
*
* Bit allocations:
*
* 76543210
- * 1 llllllcc letter-spacing | outline-color
- * 2 ooooooob outline-width | border-spacing
+ * 1 llllllcc letter-spacing | outline-color
+ * 2 ooooooob outline-width | border-spacing
* 3 bbbbbbbb border-spacing
- * 4 wwwwwwir word-spacing | counter-increment | counter-reset
- * 5 uuuuumm. cursor | writing-mode | <unused>
+ * 4 wwwwwwir word-spacing | counter-increment | counter-reset
+ * 5 uuuuumm. cursor | writing-mode | <unused>
* 6 cccccccc clip
* 7 cccccccc clip
* 8 ccccccoo clip | content
* 9 ccffssss column_count | column-fill | column-rule-style
* 10 ggggggcc column-gap | column-rule-color
*/
- uint8_t bits[10];
+ uint8_t bits[11];
css_fixed border_spacing[2];
@@ -87,6 +89,7 @@ typedef struct css_computed_uncommon {
int32_t column_count;
css_fixed column_gap;
css_color column_rule_color;
+ css_fixed column_rule_width;
css_computed_counter *counter_increment;
css_computed_counter *counter_reset;
@@ -51,27 +52,28 @@ typedef struct css_computed_uncommon {
* 6 cccccccc clip
* 7 cccccccc clip
- * 8 ccccccoo clip | content
- * 9 ccffssss column_count | column-fill | column-rule-style
- * 10 ggggggcc column-gap | column-rule-color
+ * 8 ccccccoo clip | content
+ * 9 ccffssss column_count | column-fill | column-rule-style
+ * 10 ggggggcc column-gap | column-rule-color
+ * 11 wwwwwww. column-rule-width
*/